@@ -20,21 +20,11 @@
 #include <QDir>
 
 RemoteListModel::RemoteListModel(QObject *parent) :
-    QStringListModel(parent)
+    SelectionModel(parent)
 {
-    m_roleNames[Qt::DisplayRole] = "name";
-#if QT_VERSION < 0x050000
-    this->setRoleNames(m_roleNames);
-#endif
-    this->setStringList(QDir(REMOTES_DIRECTORY).entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name));
+    QDir dir(REMOTES_DIRECTORY);
 
-    emit countChanged(this->rowCount());
+    foreach (QString fileName, dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name)) {
+        this->addItem(fileName, fileName);
+    }
 }
-
-RemoteListModel::~RemoteListModel() {}
-
-#if QT_VERSION >= 0x050000
-QHash<int, QByteArray> RemoteListModel::roleNames() const {
-    return m_roleNames;
-}
-#endif
