@@ -16,9 +16,8 @@
  */
 
 #include "remoteloader.h"
-#include "remotesettingsdialog.h"
-#include "../controls/widgets/controlloader.h"
-#include "../controls/widgets/remotepagestack.h"
+#include "controls/controlloader.h"
+#include "controls/remotepagestack.h"
 #include "../base/scriptengine.h"
 #include "../base/definitions.h"
 #include "../base/settings.h"
