@@ -177,11 +177,6 @@ void HttpPrivate::performNextRequest(bool isRedirect) {
         reply = 0;
     }
 
-    if (buffer) {
-        buffer->deleteLater();
-        buffer = 0;
-    }
-
     switch (queuedRequest.method) {
     case Http::PUT:
         reply = nam->put(request, queuedRequest.data.toUtf8());
@@ -194,7 +189,13 @@ void HttpPrivate::performNextRequest(bool isRedirect) {
         break;
     case Http::CUSTOM:
         if (!queuedRequest.data.isEmpty()) {
-            buffer = new QBuffer;
+            if (!buffer) {
+                buffer = new QBuffer;
+            }
+            else if (buffer->isOpen()) {
+                buffer->close();
+            }
+
             buffer->setData(queuedRequest.data.toUtf8());
             buffer->open(QIODevice::ReadOnly);
         }
@@ -242,7 +243,14 @@ void HttpPrivate::_q_onReplyFinished() {
     if (!queuedRequest.callback.isEmpty()) {
         QScriptValue val;
 
-        if (queuedRequest.sender.isValid()) {
+        if (queuedRequest.callback.startsWith("function")) {
+            val = ScriptEngine::instance()->evaluate(QString("(%1)").arg(queuedRequest.callback));
+
+            if (val.isFunction()) {
+                val = val.call(queuedRequest.sender, QScriptValueList() << QString(reply->readAll()));
+            }
+        }
+        else if (queuedRequest.sender.isValid()) {
             QScriptValue global = ScriptEngine::instance()->globalObject();
             val = global.property(queuedRequest.callback).call(queuedRequest.sender, QScriptValueList() << QString(reply->readAll()));
         }
