@@ -25,11 +25,14 @@
 
 class QNetworkAccessManager;
 class QNetworkReply;
+class QBuffer;
 
 struct Request {
     Http::Method method;
+    QString verb;
     QUrl url;
     QString data;
+    QVariantMap headers;
     QScriptValue sender;
     QString callback;
 };
@@ -51,6 +54,8 @@ public:
 
     QNetworkReply *reply;
 
+    QBuffer *buffer;
+
     int redirects;
 
     QQueue<Request> requests;
