@@ -18,8 +18,10 @@
 #ifndef PROTOTYPES_H
 #define PROTOTYPES_H
 
+#include "dateprototype.h"
 #include "keyeventprototype.h"
 #include "mouseeventprototype.h"
 #include "standarditemprototype.h"
+#include "timeprototype.h"
 
 #endif // PROTOTYPES_H
