@@ -5,12 +5,10 @@ var retries = 0;
 var contentHeader = { "Content-Type": "application/atom+xml" };
 
 function getIPAddress() {
-    var headers = {};
-    headers["MAN"] = "ssdp:discover";
-    headers["MX"] = "4";
-    headers["ST"] = "urn:schemas-upnp-org:device:MediaRenderer:1";
-    
-    http.send("M-SEARCH", "http://239.255.255.250:1900", "", headers, "checkIPAddress");
+    var request = new NetworkRequest();
+    request.url = "http://www.google.com";
+    request.statusChanged.connect(function () { print("Status changed"); });
+    request.get();
 }
 
 function checkIPAddress(response) {
